@@ -7,9 +7,6 @@ function (qual = NULL, workers, value = "1", notify = FALSE, name = NULL,
     auto.value = NULL, conditional.statistic = NULL, conditional.comparator = NULL, 
     conditional.value = NULL, conditional.period = NULL, set.statistic.as.value = FALSE, 
     verbose = getOption('MTurkR.verbose', TRUE), ...) {
-    # temporary check for `print` argument (remove after v1.0)
-    if('print' %in% names(list(...)) && is.null(verbose))
-        verbose <- list(...)$print
     operation <- "AssignQualification"
     if(!is.null(qual) & is.factor(qual))
         qual <- as.character(qual)
