@@ -2,9 +2,6 @@ block <-
 BlockWorker <-
 BlockWorkers <-
 function (workers, reasons, verbose = getOption('MTurkR.verbose', TRUE), ...){
-    # temporary check for `print` argument (remove after v1.0)
-    if('print' %in% names(list(...)) && is.null(verbose))
-        verbose <- list(...)$print
     operation <- "BlockWorker"
     if(is.factor(workers))
         workers <- as.character(workers)
