@@ -3,9 +3,6 @@ ContactWorker <-
 ContactWorkers <-
 function (subjects, msgs, workers, batch = FALSE,
     verbose = getOption('MTurkR.verbose', TRUE), ...) {
-    # temporary check for `print` argument (remove after v1.0)
-    if('print' %in% names(list(...)) && is.null(verbose))
-        verbose <- list(...)$print
     operation <- "NotifyWorkers"
     if(is.factor(subjects))
         subjects <- as.character(subjects)
