@@ -6,9 +6,6 @@ function(hit = NULL,
          response.group = NULL, 
          verbose = getOption('MTurkR.verbose', TRUE), 
          ...) {
-    # temporary check for `print` argument (remove after v1.0)
-    if('print' %in% names(list(...)) && is.null(verbose))
-        verbose <- list(...)$print
     operation <- "DisableHIT"
     if(!is.null(response.group)) {
         if(any(!response.group %in% 
