@@ -7,9 +7,6 @@ function(hit = NULL,
          add.seconds = NULL, 
          unique.request.token = NULL,
          verbose = getOption('MTurkR.verbose', TRUE), ...) {
-    # temporary check for `print` argument (remove after v1.0)
-    if('print' %in% names(list(...)) && is.null(verbose))
-        verbose <- list(...)$print
     operation <- "ExtendHIT"
     GETparameters <- ""
     if(is.null(add.assignments) & is.null(add.seconds)) 
