@@ -1,9 +1,6 @@
 GetQualificationType <-
 qualtype <-
 function(qual, verbose = getOption('MTurkR.verbose', TRUE), ...) {
-    # temporary check for `print` argument (remove after v1.0)
-    if('print' %in% names(list(...)) && is.null(verbose))
-        verbose <- list(...)$print
     operation <- "GetQualificationType"
     if(is.null(qual)) 
         stop("Must specify QualificationTypeId")
