@@ -9,9 +9,6 @@ function(hit,
          pagenumber = 1, 
          pagesize = 400, 
          verbose = getOption('MTurkR.verbose', TRUE), ...) {
-    # temporary check for `print` argument (remove after v1.0)
-    if('print' %in% names(list(...)) && is.null(verbose))
-        verbose <- list(...)$print
     operation <- "GetReviewResultsForHIT"
     if(is.null(hit))
         stop("Must specify HITId as 'hit'")
