@@ -2,9 +2,6 @@ GrantQualification <-
 GrantQualifications <-
 grantqual <-
 function(qual.requests, values, verbose = getOption('MTurkR.verbose', TRUE), ...) {
-    # temporary check for `print` argument (remove after v1.0)
-    if('print' %in% names(list(...)) && is.null(verbose))
-        verbose <- list(...)$print
     operation <- "GrantQualification"
     if(is.factor(qual.requests))
         qual.requests <- as.character(qual.requests)
