@@ -10,11 +10,7 @@ function (qual = NULL) {
         c("Worker_Locale", "00000000000000000071"), 
         c("Worker_Adult", "00000000000000000060"),
         c("Masters (Sandbox)","2ARFPLSP75KLA8M8DH1HTEQVJT3SY6"),
-        c("Masters (Production)","2F1QJWKUDD8XADTFD2Q0G6UTO95ALH"),
-        c("Categorization Masters (Sandbox)", "2F1KVCNHMVHV8E9PBUB2A4J79LU20F"),
-        c("Categorization Masters (Production)", "2NDP2L92HECWY8NS8H3CK0CP5L9GHO"),
-        c("Photo Moderation Masters (Sandbox)", "2TGBB6BFMFFOM08IBMAFGGESC1UWJX"),
-        c("Photo Moderation Masters (Production)", "21VZU98JHSTLZ5BPP4A9NOBJEK3DPG")
+        c("Masters (Production)","2F1QJWKUDD8XADTFD2Q0G6UTO95ALH")
         ), stringsAsFactors = FALSE), c("Qualification", "QualificationTypeId"))
     if(!is.null(qual)) 
         return(as.character(quals[quals$Qualification == qual, 2]))
