@@ -2,9 +2,6 @@ RejectQualification <-
 RejectQualifications <-
 rejectrequest <-
 function (qual.requests, reason = NULL, verbose = getOption('MTurkR.verbose', TRUE), ...){
-    # temporary check for `print` argument (remove after v1.0)
-    if('print' %in% names(list(...)) && is.null(verbose))
-        verbose <- list(...)$print
     operation <- "RejectQualificationRequest"
     if(is.factor(qual.requests))
         qual.requests <- as.character(qual.requests)
