@@ -2,9 +2,6 @@ RevokeQualification <-
 RevokeQualifications <-
 revokequal <-
 function (qual, worker, reason = NULL, verbose = getOption('MTurkR.verbose', TRUE), ...){
-    # temporary check for `print` argument (remove after v1.0)
-    if('print' %in% names(list(...)) && is.null(verbose))
-        verbose <- list(...)$print
     operation <- "RevokeQualification"
     if(is.factor(qual))
         qual <- as.character(qual)
