@@ -2,9 +2,6 @@ SendTestEventNotification <-
 notificationtest <-
 function (notification, test.event.type = "HITExpired",
     verbose = getOption('MTurkR.verbose', TRUE), ...) {
-    # temporary check for `print` argument (remove after v1.0)
-    if('print' %in% names(list(...)) && is.null(verbose))
-        verbose <- list(...)$print
     operation <- "SendTestEventNotification"
     if(!test.event.type %in% c("AssignmentAccepted", "AssignmentAbandoned", 
         "AssignmentReturned", "AssignmentSubmitted", "HITReviewable", "HITExpired", "Ping")) 
