@@ -5,9 +5,6 @@ function(hit = NULL,
          annotation = NULL,
          revert = FALSE, 
          verbose = getOption('MTurkR.verbose', TRUE), ...){
-    # temporary check for `print` argument (remove after v1.0)
-    if('print' %in% names(list(...)) && is.null(verbose))
-        verbose <- list(...)$print
     operation <- "SetHITAsReviewing"
     if(revert == TRUE) 
         revert <- "true"
