@@ -2,9 +2,6 @@ UnblockWorker <-
 UnblockWorkers <-
 unblock <-
 function (workers, reasons = NULL, verbose = getOption('MTurkR.verbose', TRUE), ...){
-    # temporary check for `print` argument (remove after v1.0)
-    if('print' %in% names(list(...)) && is.null(verbose))
-        verbose <- list(...)$print
     operation <- "UnblockWorker"
     if(is.factor(workers))
         workers <- as.character(workers)
