@@ -2,9 +2,6 @@ UpdateQualificationScore <-
 updatequalscore <-
 function (qual, workers, values = NULL, increment = NULL,
     verbose = getOption('MTurkR.verbose', TRUE), ...){
-    # temporary check for `print` argument (remove after v1.0)
-    if('print' %in% names(list(...)) && is.null(verbose))
-        verbose <- list(...)$print
     operation <- "UpdateQualificationScore"
     if(is.factor(qual))
         qual <- as.character(qual)
