@@ -4,6 +4,6 @@ function (parameter, value) {
         stop("Parameter and Value have unequal length")
     GET <- ""
     for(i in 1:length(parameter))
-        GET <- paste(GET, "&", parameter[i], "=", curlEscape(value[i]), sep = "")
+        GET <- paste(GET, "&", parameter[i], "=", curl_escape(value[i]), sep = "")
     return(GET)
 }
