@@ -1,6 +1,7 @@
 request <-
 function(operation, GETparameters = NULL,
-    keypair = getOption('MTurkR.keypair'),
+    keypair = c(Sys.getenv("AWS_ACCESS_KEY_ID"), 
+                Sys.getenv("AWS_SECRET_ACCESS_KEY")),
     browser = getOption('MTurkR.browser', FALSE),
     log.requests = getOption('MTurkR.log', TRUE), 
     sandbox = getOption('MTurkR.sandbox', FALSE),
@@ -9,17 +10,18 @@ function(operation, GETparameters = NULL,
     service = "AWSMechanicalTurkRequester",
     version = NULL)
 {
-    if(sandbox) 
+    if(sandbox) {
         host <- "https://mechanicalturk.sandbox.amazonaws.com/"
-    else
+    } else {
         host <- "https://mechanicalturk.amazonaws.com/"
-    if(is.null(keypair)) {
-        key <- Sys.getenv("AWS_ACCESS_KEY_ID")
-        secret <- Sys.getenv("AWS_SECRET_ACCESS_KEY")
-        if(key != "" & secret != "") {
-            options(MTurkR.keypair = c(key,secret))
+    }
+    if (is.null(keypair) || identical(keypair, c("", "")) || keypair == "") {
+        g <- getOption("MTurkR.keypair")
+        if (!is.null(g)) {
+            keypair <- g
+            warning("Credentials must be set in environment variables: AWS_ACCESS_KEY_ID and AWS_SECRET_ACCESS_KEY")
         } else {
-            stop("No keypair provided or 'credentials' object not stored")
+            stop("No keypair provided.\nPlease set environment variables: AWS_ACCESS_KEY_ID and AWS_SECRET_ACCESS_KEY")
         }
     }
     keyid <- keypair[1]
@@ -35,7 +37,7 @@ function(operation, GETparameters = NULL,
                            "&Signature=", curl_escape(signature), 
                            GETparameters, sep = "")
     request.url <- paste(host, urlparameters, sep='')
-    if(validation.test){
+    if (validation.test) {
         message("Request URL: ",request.url,'\n')
         return(structure(list(operation = operation,
                               request.id = NULL,
@@ -43,9 +45,8 @@ function(operation, GETparameters = NULL,
                               valid = NULL,
                               xml = NULL),
                          class='MTurkResponse'))
-    }
-    else {
-        if(browser == TRUE) {
+    } else {
+        if (browser == TRUE) {
             browseURL(request.url)
             return(structure(list(operation = operation,
                                   request.id = NULL,
@@ -58,7 +59,6 @@ function(operation, GETparameters = NULL,
             fetch <- curl_fetch_memory(url = host, handle = h)
             response <- rawToChar(fetch$content)
 
-            # Additional filters, added by Solomon Messing 6/9/2013:
             clean <- function(x, pattern, replacement){
                 res <- gsub( iconv(pattern, "", "ASCII", "byte"), replacement, x, fixed=T)
                 return(res)
@@ -88,13 +88,14 @@ function(operation, GETparameters = NULL,
             valid.test <-
                 strsplit(strsplit(response, "<Request><IsValid>")[[1]][2],
                     "</IsValid>")[[1]][1]
-            if(!is.na(valid.test) && valid.test == "True") 
+            if (!is.na(valid.test) && valid.test == "True")  {
                 valid <- TRUE
-            else if(!is.na(valid.test) && valid.test == "False") 
+            } else if(!is.na(valid.test) && valid.test == "False") {
                 valid <- FALSE
-            else
+            } else {
                 valid <- FALSE
-            if(log.requests == TRUE) {
+            }
+            if (log.requests == TRUE) {
                 towrite <- paste("Timestamp\t",
                                  "RequestId\t",
                                  "Operation\t", 
@@ -104,11 +105,9 @@ function(operation, GETparameters = NULL,
                                  "URL\t", 
                                  "Response", sep = "")
                 logfilename <- file.path(getOption('MTurkR.logdir', getwd()),"MTurkRlog.tsv")
-                if(!"MTurkRlog.tsv" %in% list.files(path=getOption('MTurkR.logdir', getwd()))) {
+                if (!"MTurkRlog.tsv" %in% list.files(path=getOption('MTurkR.logdir', getwd()))) {
                     tryCatch(write(towrite, logfilename),
-                        error=function(e){
-                            warning('Writing to new MTurkR log failed!')
-                        })
+                             error = function(e){ warning('Writing to new MTurkR log failed!') })
                 }
                 response.xml <- response
                 response.xml <- gsub(" ", "#!SPACE!#", response.xml, fixed = TRUE)
@@ -129,25 +128,27 @@ function(operation, GETparameters = NULL,
                                   request.url, "\t",
                                   response.xml, sep = "")
                 tryCatch(write(towrite2, logfilename, append = TRUE),
-                        error=function(e){
+                         error = function(e){
                             warning(paste('Writing to MTurkR log failed!\n',
-                                          'Log contents were:\n',towrite2))
+                                          'Log contents were:\n', towrite2))
                         })
             }
-            if(!valid && verbose) {
+            if (!valid && verbose) {
                 message("Request ", request.id, " not valid for API request:")
-                temp.url <- gsub('=',' = ',request.url)
-                if(sandbox) {
-                    message(paste(paste(strsplit(temp.url, "&")[[1]],
+                temp_url <- request.url
+                temp_url <- gsub("AWSAccessKeyId=.+(?=&)", "AWSAccessKeyId=REDACTED", temp_url, perl = TRUE)
+                temp_url <- gsub('=',' = ', temp_url)
+                if (sandbox) {
+                    message(paste(paste(strsplit(temp_url, "&")[[1]],
                       collapse="\n                                             &"),'\n\n'))
                 } else {
-                    message(paste(paste(strsplit(temp.url, "&")[[1]],
+                    message(paste(paste(strsplit(temp_url, "&")[[1]],
                       collapse="\n                                     &"),'\n\n'))
                 }
                 ParseErrorCodes <- function(xml) {
                     xml.errors <- xpathApply(xmlParse(xml), "//Error")
                     errors <- setNames(data.frame(matrix(nrow = length(xml.errors), ncol = 2)),
-                                c("Code", "Message"))
+                                       c("Code", "Message"))
                     for(i in 1:length(xml.errors)) {
                         errors[i,] <- c(xmlValue(xpathApply(xml.errors[[i]], "//Code")[[1]]),
                                         xmlValue(xpathApply(xml.errors[[i]], "//Message")[[1]]))
@@ -155,44 +156,47 @@ function(operation, GETparameters = NULL,
                     return(invisible(errors))
                 }
                 errors <- tryCatch(ParseErrorCodes(xml = response), error = function(e) e)
-                if(!inherits(errors, 'error')){
-                    cat('\n')
-                    for (i in 1:dim(errors)[1])
-                        message("Error (", errors[i, 1], "): ", errors[i,2])
+                if (!inherits(errors, 'error')) {
+                    for (i in 1:dim(errors)[1]) {
+                        message("Error (", errors[i, 1], "):\n  ", errors[i,2])
+                    }
                 }
             }
             return(structure(list(operation = operation,
                                   request.id = request.id, 
                                   valid = valid, 
-                                  request.url = request.url,
+                                  request.url = host,
+                                  body = urlparameters,
                                   xml = response), 
-                             class='MTurkResponse'))
+                             class = 'MTurkResponse'))
         }
     }
 }
 
 print.MTurkResponse <- function(x,...){
-    if(!is.null(x$operation))
+    if (!is.null(x$operation)) {
         cat('API Operation: ',x$operation,'\n')
-    if(!is.null(x$request.id))
-        cat('RequestId:     ',x$request.id,'\n')
-    if(!is.null(x$valid))
-        cat('Valid?         ',x$valid,'\n')
-    if(!is.null(x$request.url))
-        cat('Request URL:   ',gsub('&','\n',curl_unescape(x$request.url),'\n'))
-    if(!is.null(x$xml)){
-        cat('XML Response:\n')
-        print(xmlParse(x$response))
     }
-    cat('\n')
+    if (!is.null(x$request.id)) {
+        cat('RequestId:     ',x$request.id,'\n')
+    }
+    if (!is.null(x$valid)) {
+        cat('Valid?         ',x$valid,'\n')
+    }
+    if (!is.null(x$request.url)) {
+        cat('Service:       ', curl_unescape(x$request.url),'\n')
+    }
+    if (!is.null(x$body)) {
+        temp <- x$body
+        temp <- gsub("AWSAccessKeyId=.+(?=&)", "AWSAccessKeyId=REDACTED", temp, perl = TRUE)
+        cat('Parameters:    ',gsub('(?<!^)&','\n                 ',curl_unescape(temp), perl = TRUE),'\n')
+    }
     invisible(x)
 }
 
 as.data.frame.MTurkResponse <- function(x, ...){
     xml.parsed <- xmlParse(x$xml)
     n <- xmlName(xmlRoot(xml.parsed))
-    #class(x$xml) <- 'test' # something to switch to appropriate parsing function
-    # class(xml.parsed) <- switch(n, # list of switches here from API methods to as.data.frame methods )
     out <- as.data.frame(xml.parsed)
     invisible(out)
 }
